@@ -11,8 +11,6 @@ from datamodel_code_generator.model import (
     DataModelFieldBase,
 )
 from datamodel_code_generator.model.pydantic.imports import IMPORT_EXTRA, IMPORT_FIELD
-from datamodel_code_generator.model.pydantic.types import get_data_type
-from datamodel_code_generator.types import DataType, Types
 
 
 class Constraints(ConstraintsBase):
@@ -88,6 +86,7 @@ class BaseModel(DataModel):
         auto_import: bool = True,
         reference_classes: Optional[List[str]] = None,
         imports: Optional[List[Import]] = None,
+        path: Optional[Path] = None,
     ):
 
         methods: List[str] = [field.method for field in fields if field.method]
@@ -104,6 +103,7 @@ class BaseModel(DataModel):
             reference_classes=reference_classes,
             imports=imports,
             methods=methods,
+            path=path,
         )
 
         config_parameters: Dict[str, Any] = {}
@@ -123,7 +123,3 @@ class BaseModel(DataModel):
         for field in fields:
             if field.field:
                 self.imports.append(IMPORT_FIELD)
-
-    @classmethod
-    def get_data_type(cls, types: Types, **kwargs: Any) -> DataType:
-        return get_data_type(types, **kwargs).copy()
