@@ -235,7 +235,11 @@ class JsonSchemaParser(Parser):
     @root_id.setter
     def root_id(self, value: Optional[str]) -> None:
         self._root_id = value
-        self._root_id_base_path = value.rsplit('/', 1)[0] if value else None
+        if value and '/' in value:
+            self._root_id_base_path = value.rsplit('/', 1)[0]
+        else:
+            self._root_id_base_path = None
+
         self.model_resolver.set_root_id_base_path(self.root_id_base_path)
 
     @property
@@ -666,7 +670,7 @@ class JsonSchemaParser(Parser):
             singular_name_suffix='Enum',
             unique=unique,
         ).name
-        enum = Enum(enum_name, fields=enum_fields)
+        enum = Enum(enum_name, fields=enum_fields, path=self.current_source_path)
         self.append_result(enum)
         return enum
 
@@ -693,7 +697,10 @@ class JsonSchemaParser(Parser):
             else:
                 # Remote Reference – $ref: 'document.json' Uses the whole document located on the same server and in
                 # the same location. TODO treat edge case
-                full_path = self.base_path / ref
+                if self.current_source_path and len(self.current_source_path.parts) > 1:
+                    full_path = self.base_path / self.current_source_path.parent / ref
+                else:
+                    full_path = self.base_path / ref
                 # yaml loader can parse json data.
                 with full_path.open() as f:
                     ref_body = yaml.safe_load(f)
@@ -708,6 +715,8 @@ class JsonSchemaParser(Parser):
                 if obj.ref.startswith('#'):
                     # Local Reference – $ref: '#/definitions/myElement'
                     pass
+                elif self.model_resolver.is_after_load(obj.ref):
+                    pass
                 else:
                     if (
                         not obj.ref.startswith(('https://', 'http://'))
@@ -716,8 +725,10 @@ class JsonSchemaParser(Parser):
                         ref = f'{self.root_id_base_path}/{obj.ref}'
                     else:
                         ref = obj.ref
-                    if '#/' in ref:
+                    if self.model_resolver.is_external_ref(ref):
                         relative_path, object_path = ref.split('#/')
+                    elif self.model_resolver.is_external_root_ref(ref):
+                        relative_path, object_path = ref[:-1], ''
                     else:
                         relative_path, object_path = ref, ''
                     object_paths = object_path.split('/')
@@ -728,11 +739,21 @@ class JsonSchemaParser(Parser):
                         model_name = object_paths[-1]
                     else:
                         models = ref_body
-                        model_name = models.get('title', 'Model')
-                    with self.root_id_context(self.raw_obj):
-                        self.parse_raw_obj(
-                            model_name, models, [relative_path, '#', *object_paths]
-                        )
+                        model_name = self.model_resolver.add_ref(obj.ref).name
+                    if not obj.ref.startswith(('https://', 'http://')):
+                        previous_base_path: Optional[Path] = self.base_path
+                        self.base_path = (self.base_path / relative_path).parent
+                    else:
+                        previous_base_path = None
+                    relative_paths = relative_path.split('/')
+                    self._parse_file(
+                        models,
+                        model_name,
+                        [*relative_paths, '#', *object_paths],
+                        relative_paths,
+                    )
+                    if previous_base_path:
+                        self.base_path = previous_base_path
                     self.model_resolver.add_ref(
                         ref, actual_module_name=''
                     ).loaded = True
@@ -811,6 +832,9 @@ class JsonSchemaParser(Parser):
             isinstance(self.source, Path) and self.source.is_dir()
         ):
             self.current_source_path = Path()
+            self.model_resolver.after_load_files = [
+                str(s.path) for s in self.iter_source
+            ]
         for source in self.iter_source:
             if self.current_source_path is not None:
                 self.current_source_path = source.path
@@ -824,19 +848,31 @@ class JsonSchemaParser(Parser):
                 obj_name = self.raw_obj.get('title', 'Model')
                 if not self.model_resolver.validate_name(obj_name):
                     raise InvalidClassNameError(obj_name)
+            self._parse_file(self.raw_obj, obj_name, path_parts, path_parts)
 
-            obj_name = self.model_resolver.add(path_parts, obj_name, unique=False).name
-            root_obj = JsonSchemaObject.parse_obj(self.raw_obj)
-            with self.root_id_context(self.raw_obj):
-                definitions = self.raw_obj.get('definitions', {})
+    def _parse_file(
+        self,
+        raw: Dict[str, Any],
+        obj_name: str,
+        path_parts: List[str],
+        root_path: List[str],
+    ) -> None:
+        previous_root_path: List[str] = self.model_resolver.current_root
+        self.model_resolver.set_current_root(root_path)
 
-                # parse $id before parsing $ref
-                self.parse_id(root_obj, path_parts)
-                for key, model in definitions.items():
-                    obj = JsonSchemaObject.parse_obj(model)
-                    self.parse_id(obj, [*path_parts, '#/definitions', key])
+        obj_name = self.model_resolver.add(path_parts, obj_name, unique=False).name
+        root_obj = JsonSchemaObject.parse_obj(raw)
+        with self.root_id_context(raw):
+            definitions = raw.get('definitions', {})
 
-                self.parse_obj(obj_name, root_obj, path_parts)
-                definitions = self.raw_obj.get('definitions', {})
-                for key, model in definitions.items():
-                    self.parse_raw_obj(key, model, [*path_parts, '#/definitions', key])
+            # parse $id before parsing $ref
+            self.parse_id(root_obj, path_parts)
+            for key, model in definitions.items():
+                obj = JsonSchemaObject.parse_obj(model)
+                self.parse_id(obj, [*path_parts, '#/definitions', key])
+
+            self.parse_obj(obj_name, root_obj, path_parts)
+            definitions = raw.get('definitions', {})
+            for key, model in definitions.items():
+                self.parse_raw_obj(key, model, [*path_parts, '#/definitions', key])
+        self.model_resolver.set_current_root(previous_root_path)
