@@ -21,7 +21,11 @@ class Reference(BaseModel):
             return None
         # TODO: Support file:///
         path = Path(self.path.split('#')[0])
-        module_name = f'{".".join(path.parts[:-1][1:])}.{path.stem}'
+
+        # workaround: If a file name has dot then, this method uses first part.
+        module_name = f'{".".join(path.parts[:-1])}.{path.stem.split(".")[0]}'
+        if module_name.startswith(f'.{self.name.split(".", 1)[0]}'):
+            return None
         if module_name == '.':
             return None
         return module_name
@@ -37,6 +41,7 @@ class ModelResolver:
         self._current_root: List[str] = []
         self._root_id_base_path: Optional[str] = None
         self.ids: DefaultDict[str, Dict[str, str]] = defaultdict(dict)
+        self.after_load_files: List[str] = []
 
     @property
     def current_root(self) -> List[str]:
@@ -67,6 +72,23 @@ class ModelResolver:
             return f'{self.root_id_base_path}/{joined_path}#/'
         return f'{joined_path}#/'
 
+    def is_after_load(self, ref: str) -> bool:
+        if self.current_root and len(self.current_root) > 1:
+            ref = f"{'/'.join(self.current_root[:-1])}/{ref}"
+        if self.is_external_ref(ref):
+            return ref.split('#/', 1)[0] in self.after_load_files
+        elif self.is_external_root_ref(ref):
+            return ref[:-1] in self.after_load_files
+        return False
+
+    @staticmethod
+    def is_external_ref(ref: str) -> bool:
+        return '#/' in ref
+
+    @staticmethod
+    def is_external_root_ref(ref: str) -> bool:
+        return ref[-1] == '#'
+
     def add_ref(self, ref: str, actual_module_name: Optional[str] = None) -> Reference:
         path = self._get_path(ref.split('/'))
         reference = self.references.get(path)
@@ -75,10 +97,23 @@ class ModelResolver:
             return reference
         split_ref = ref.rsplit('/', 1)
         if len(split_ref) == 1:
-            parents, original_name = self.root_id_base_path, Path(split_ref[0]).stem
+            parents = self.root_id_base_path
+            original_name = Path(
+                split_ref[0][:-1] if self.is_external_root_ref(ref) else split_ref[0]
+            ).stem
         else:
-            parents, original_name = split_ref
-        loaded: bool = not ref.startswith(('https://', 'http://'))
+            parents = split_ref[0]
+            original_name = (
+                Path(split_ref[1][:-1]).stem
+                if self.is_external_root_ref(ref)
+                else split_ref[1]
+            )
+        if self.is_after_load(ref):
+            loaded: bool = False
+        else:
+            loaded = not self.is_external_ref(ref) and not self.is_external_root_ref(
+                ref
+            )
         if not original_name:
             original_name = Path(parents).stem  # type: ignore
             loaded = False
