@@ -1040,6 +1040,31 @@ def test_main_jsonschema_id_as_stdin(monkeypatch):
         main()
 
 
+def test_main_jsonschema_ids(tmpdir_factory: TempdirFactory) -> None:
+    output_directory = Path(tmpdir_factory.mktemp('output'))
+
+    input_filename = JSON_SCHEMA_DATA_PATH / 'ids' / 'Organization.schema.json'
+    output_path = output_directory / 'model'
+
+    with freeze_time(TIMESTAMP):
+        main(
+            [
+                '--input',
+                str(input_filename),
+                '--output',
+                str(output_path),
+                '--input-file-type',
+                'jsonschema',
+            ]
+        )
+    main_jsonschema_ids_dir = EXPECTED_MAIN_PATH / 'main_jsonschema_ids'
+    for path in main_jsonschema_ids_dir.rglob('*.py'):
+        result = output_path.joinpath(
+            path.relative_to(main_jsonschema_ids_dir)
+        ).read_text()
+        assert result == path.read_text()
+
+
 def test_main_use_standard_collections(tmpdir_factory: TempdirFactory) -> None:
     output_directory = Path(tmpdir_factory.mktemp('output'))
 
@@ -1064,3 +1089,82 @@ def test_main_use_standard_collections(tmpdir_factory: TempdirFactory) -> None:
             path.relative_to(main_use_standard_collections_dir)
         ).read_text()
         assert result == path.read_text()
+
+
+@freeze_time('2019-07-26')
+def test_main_external_definitions():
+    with TemporaryDirectory() as output_dir:
+        output_file: Path = Path(output_dir) / 'output.py'
+        return_code: Exit = main(
+            [
+                '--input',
+                str(JSON_SCHEMA_DATA_PATH / 'external_definitions_root.json'),
+                '--output',
+                str(output_file),
+                '--input-file-type',
+                'jsonschema',
+            ]
+        )
+        assert return_code == Exit.OK
+        assert (
+            output_file.read_text()
+            == (
+                EXPECTED_MAIN_PATH / 'main_external_definitions' / 'output.py'
+            ).read_text()
+        )
+    with pytest.raises(SystemExit):
+        main()
+
+
+@freeze_time('2019-07-26')
+def test_main_external_files_in_directory(tmpdir_factory: TempdirFactory) -> None:
+    with TemporaryDirectory() as output_dir:
+        output_file: Path = Path(output_dir) / 'output.py'
+        return_code: Exit = main(
+            [
+                '--input',
+                str(
+                    JSON_SCHEMA_DATA_PATH
+                    / 'external_files_in_directory'
+                    / 'person.json'
+                ),
+                '--output',
+                str(output_file),
+                '--input-file-type',
+                'jsonschema',
+            ]
+        )
+        assert return_code == Exit.OK
+        assert (
+            output_file.read_text()
+            == (
+                EXPECTED_MAIN_PATH / 'main_external_files_in_directory' / 'output.py'
+            ).read_text()
+        )
+    with pytest.raises(SystemExit):
+        main()
+
+
+@freeze_time('2019-07-26')
+def test_main_nested_directory(tmpdir_factory: TempdirFactory) -> None:
+    output_directory = Path(tmpdir_factory.mktemp('output'))
+
+    output_path = output_directory / 'model'
+    return_code: Exit = main(
+        [
+            '--input',
+            str(JSON_SCHEMA_DATA_PATH / 'external_files_in_directory'),
+            '--output',
+            str(output_path),
+            '--input-file-type',
+            'jsonschema',
+        ]
+    )
+    assert return_code == Exit.OK
+    main_nested_directory = EXPECTED_MAIN_PATH / 'main_nested_directory'
+
+    for path in main_nested_directory.rglob('*.py'):
+        result = output_path.joinpath(
+            path.relative_to(main_nested_directory)
+        ).read_text()
+        assert result == path.read_text()
